# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Cognito User Pools'
prefix = 'cognito-idp'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AddCustomAttributes = Action('AddCustomAttributes')
AdminAddUserToGroup = Action('AdminAddUserToGroup')
AdminConfirmSignUp = Action('AdminConfirmSignUp')
AdminCreateUser = Action('AdminCreateUser')
AdminDeleteUser = Action('AdminDeleteUser')
AdminDeleteUserAttributes = Action('AdminDeleteUserAttributes')
AdminDisableProviderForUser = Action('AdminDisableProviderForUser')
AdminDisableUser = Action('AdminDisableUser')
AdminEnableUser = Action('AdminEnableUser')
AdminForgetDevice = Action('AdminForgetDevice')
AdminGetDevice = Action('AdminGetDevice')
AdminGetUser = Action('AdminGetUser')
AdminInitiateAuth = Action('AdminInitiateAuth')
AdminLinkProviderForUser = Action('AdminLinkProviderForUser')
AdminListDevices = Action('AdminListDevices')
AdminListGroupsForUser = Action('AdminListGroupsForUser')
AdminListUserAuthEvents = Action('AdminListUserAuthEvents')
AdminRemoveUserFromGroup = Action('AdminRemoveUserFromGroup')
AdminResetUserPassword = Action('AdminResetUserPassword')
AdminRespondToAuthChallenge = Action('AdminRespondToAuthChallenge')
AdminSetUserMFAPreference = Action('AdminSetUserMFAPreference')
AdminSetUserPassword = Action('AdminSetUserPassword')
AdminSetUserSettings = Action('AdminSetUserSettings')
AdminUpdateAuthEventFeedback = Action('AdminUpdateAuthEventFeedback')
AdminUpdateDeviceStatus = Action('AdminUpdateDeviceStatus')
AdminUpdateUserAttributes = Action('AdminUpdateUserAttributes')
AdminUserGlobalSignOut = Action('AdminUserGlobalSignOut')
AssociateSoftwareToken = Action('AssociateSoftwareToken')
ChangePassword = Action('ChangePassword')
ConfirmDevice = Action('ConfirmDevice')
ConfirmForgotPassword = Action('ConfirmForgotPassword')
ConfirmSignUp = Action('ConfirmSignUp')
CreateGroup = Action('CreateGroup')
CreateIdentityProvider = Action('CreateIdentityProvider')
CreateResourceServer = Action('CreateResourceServer')
CreateUserImportJob = Action('CreateUserImportJob')
CreateUserPool = Action('CreateUserPool')
CreateUserPoolClient = Action('CreateUserPoolClient')
CreateUserPoolDomain = Action('CreateUserPoolDomain')
DeleteGroup = Action('DeleteGroup')
DeleteIdentityProvider = Action('DeleteIdentityProvider')
DeleteResourceServer = Action('DeleteResourceServer')
DeleteUser = Action('DeleteUser')
DeleteUserAttributes = Action('DeleteUserAttributes')
DeleteUserPool = Action('DeleteUserPool')
DeleteUserPoolClient = Action('DeleteUserPoolClient')
DeleteUserPoolDomain = Action('DeleteUserPoolDomain')
DescribeIdentityProvider = Action('DescribeIdentityProvider')
DescribeResourceServer = Action('DescribeResourceServer')
DescribeRiskConfiguration = Action('DescribeRiskConfiguration')
DescribeUserImportJob = Action('DescribeUserImportJob')
DescribeUserPool = Action('DescribeUserPool')
DescribeUserPoolClient = Action('DescribeUserPoolClient')
DescribeUserPoolDomain = Action('DescribeUserPoolDomain')
ForgetDevice = Action('ForgetDevice')
ForgotPassword = Action('ForgotPassword')
GetCSVHeader = Action('GetCSVHeader')
GetDevice = Action('GetDevice')
GetGroup = Action('GetGroup')
GetIdentityProviderByIdentifier = \
    Action('GetIdentityProviderByIdentifier')
GetSigningCertificate = Action('GetSigningCertificate')
GetUICustomization = Action('GetUICustomization')
GetUser = Action('GetUser')
GetUserAttributeVerificationCode = \
    Action('GetUserAttributeVerificationCode')
GetUserPoolMfaConfig = Action('GetUserPoolMfaConfig')
GlobalSignOut = Action('GlobalSignOut')
InitiateAuth = Action('InitiateAuth')
ListDevices = Action('ListDevices')
ListGroups = Action('ListGroups')
ListIdentityProviders = Action('ListIdentityProviders')
ListResourceServers = Action('ListResourceServers')
ListTagsForResource = Action('ListTagsForResource')
ListUserImportJobs = Action('ListUserImportJobs')
ListUserPoolClients = Action('ListUserPoolClients')
ListUserPools = Action('ListUserPools')
ListUsers = Action('ListUsers')
ListUsersInGroup = Action('ListUsersInGroup')
ResendConfirmationCode = Action('ResendConfirmationCode')
RespondToAuthChallenge = Action('RespondToAuthChallenge')
SetRiskConfiguration = Action('SetRiskConfiguration')
SetUICustomization = Action('SetUICustomization')
SetUserMFAPreference = Action('SetUserMFAPreference')
SetUserPoolMfaConfig = Action('SetUserPoolMfaConfig')
SetUserSettings = Action('SetUserSettings')
SignUp = Action('SignUp')
StartUserImportJob = Action('StartUserImportJob')
StopUserImportJob = Action('StopUserImportJob')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateAuthEventFeedback = Action('UpdateAuthEventFeedback')
UpdateDeviceStatus = Action('UpdateDeviceStatus')
UpdateGroup = Action('UpdateGroup')
UpdateIdentityProvider = Action('UpdateIdentityProvider')
UpdateResourceServer = Action('UpdateResourceServer')
UpdateUserAttributes = Action('UpdateUserAttributes')
UpdateUserPool = Action('UpdateUserPool')
UpdateUserPoolClient = Action('UpdateUserPoolClient')
UpdateUserPoolDomain = Action('UpdateUserPoolDomain')
VerifySoftwareToken = Action('VerifySoftwareToken')
VerifyUserAttribute = Action('VerifyUserAttribute')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Cognito Sync'
prefix = 'cognito-sync'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


BulkPublish = Action('BulkPublish')
DeleteDataset = Action('DeleteDataset')
DescribeDataset = Action('DescribeDataset')
DescribeIdentityPoolUsage = Action('DescribeIdentityPoolUsage')
DescribeIdentityUsage = Action('DescribeIdentityUsage')
GetBulkPublishDetails = Action('GetBulkPublishDetails')
GetCognitoEvents = Action('GetCognitoEvents')
GetIdentityPoolConfiguration = Action('GetIdentityPoolConfiguration')
ListDatasets = Action('ListDatasets')
ListIdentityPoolUsage = Action('ListIdentityPoolUsage')
ListRecords = Action('ListRecords')
QueryRecords = Action('QueryRecords')
RegisterDevice = Action('RegisterDevice')
SetCognitoEvents = Action('SetCognitoEvents')
SetDatasetConfiguration = Action('SetDatasetConfiguration')
SetIdentityPoolConfiguration = Action('SetIdentityPoolConfiguration')
SubscribeToDataset = Action('SubscribeToDataset')
UnsubscribeFromDataset = Action('UnsubscribeFromDataset')
UpdateRecords = Action('UpdateRecords')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Managed Blockchain'
prefix = 'managedblockchain'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateMember = Action('CreateMember')
CreateNetwork = Action('CreateNetwork')
CreateNode = Action('CreateNode')
CreateProposal = Action('CreateProposal')
DeleteMember = Action('DeleteMember')
DeleteNode = Action('DeleteNode')
GetMember = Action('GetMember')
GetNetwork = Action('GetNetwork')
GetNode = Action('GetNode')
GetProposal = Action('GetProposal')
ListInvitations = Action('ListInvitations')
ListMembers = Action('ListMembers')
ListNetworks = Action('ListNetworks')
ListNodes = Action('ListNodes')
ListProposalVotes = Action('ListProposalVotes')
ListProposals = Action('ListProposals')
RejectInvitation = Action('RejectInvitation')
VoteOnProposal = Action('VoteOnProposal')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS DeepLens'
prefix = 'deeplens'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AssociateServiceRoleToAccount = Action('AssociateServiceRoleToAccount')
BatchGetDevice = Action('BatchGetDevice')
BatchGetModel = Action('BatchGetModel')
BatchGetProject = Action('BatchGetProject')
CreateDeviceCertificates = Action('CreateDeviceCertificates')
CreateModel = Action('CreateModel')
CreateProject = Action('CreateProject')
DeleteModel = Action('DeleteModel')
DeleteProject = Action('DeleteProject')
DeployProject = Action('DeployProject')
DeregisterDevice = Action('DeregisterDevice')
GetAssociatedResources = Action('GetAssociatedResources')
GetDeploymentStatus = Action('GetDeploymentStatus')
GetDevice = Action('GetDevice')
GetModel = Action('GetModel')
GetProject = Action('GetProject')
ImportProjectFromTemplate = Action('ImportProjectFromTemplate')
ListDeployments = Action('ListDeployments')
ListDevices = Action('ListDevices')
ListModels = Action('ListModels')
ListProjects = Action('ListProjects')
RegisterDevice = Action('RegisterDevice')
RemoveProject = Action('RemoveProject')
UpdateProject = Action('UpdateProject')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Firewall Manager'
prefix = 'fms'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AssociateAdminAccount = Action('AssociateAdminAccount')
DeleteNotificationChannel = Action('DeleteNotificationChannel')
DeletePolicy = Action('DeletePolicy')
DisassociateAdminAccount = Action('DisassociateAdminAccount')
GetAdminAccount = Action('GetAdminAccount')
GetComplianceDetail = Action('GetComplianceDetail')
GetNotificationChannel = Action('GetNotificationChannel')
GetPolicy = Action('GetPolicy')
GetProtectionStatus = Action('GetProtectionStatus')
ListComplianceStatus = Action('ListComplianceStatus')
ListMemberAccounts = Action('ListMemberAccounts')
ListPolicies = Action('ListPolicies')
PutNotificationChannel = Action('PutNotificationChannel')
PutPolicy = Action('PutPolicy')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Elemental MediaLive'
prefix = 'medialive'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


BatchUpdateSchedule = Action('BatchUpdateSchedule')
CreateChannel = Action('CreateChannel')
CreateInput = Action('CreateInput')
CreateInputSecurityGroup = Action('CreateInputSecurityGroup')
CreateTags = Action('CreateTags')
DeleteChannel = Action('DeleteChannel')
DeleteInput = Action('DeleteInput')
DeleteInputSecurityGroup = Action('DeleteInputSecurityGroup')
DeleteReservation = Action('DeleteReservation')
DeleteTags = Action('DeleteTags')
DescribeChannel = Action('DescribeChannel')
DescribeInput = Action('DescribeInput')
DescribeInputSecurityGroup = Action('DescribeInputSecurityGroup')
DescribeOffering = Action('DescribeOffering')
DescribeReservation = Action('DescribeReservation')
DescribeSchedule = Action('DescribeSchedule')
ListChannels = Action('ListChannels')
ListInputSecurityGroups = Action('ListInputSecurityGroups')
ListInputs = Action('ListInputs')
ListOfferings = Action('ListOfferings')
ListReservations = Action('ListReservations')
ListTagsForResource = Action('ListTagsForResource')
PurchaseOffering = Action('PurchaseOffering')
StartChannel = Action('StartChannel')
StopChannel = Action('StopChannel')
UpdateChannel = Action('UpdateChannel')
UpdateChannelClass = Action('UpdateChannelClass')
UpdateInput = Action('UpdateInput')
UpdateInputSecurityGroup = Action('UpdateInputSecurityGroup')
UpdateReservation = Action('UpdateReservation')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon EC2 Container Service'
prefix = 'ecs'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateCluster = Action('CreateCluster')
CreateService = Action('CreateService')
CreateTaskSet = Action('CreateTaskSet')
DeleteAccountSetting = Action('DeleteAccountSetting')
DeleteAccountSettings = Action('DeleteAccountSettings')
DeleteAttributes = Action('DeleteAttributes')
DeleteCluster = Action('DeleteCluster')
DeleteService = Action('DeleteService')
DeleteTaskSet = Action('DeleteTaskSet')
DeregisterContainerInstance = Action('DeregisterContainerInstance')
DeregisterTaskDefinition = Action('DeregisterTaskDefinition')
DescribeClusters = Action('DescribeClusters')
DescribeContainerInstances = Action('DescribeContainerInstances')
DescribeServices = Action('DescribeServices')
DescribeTaskDefinition = Action('DescribeTaskDefinition')
DescribeTaskSets = Action('DescribeTaskSets')
DescribeTasks = Action('DescribeTasks')
DiscoverPollEndpoint = Action('DiscoverPollEndpoint')
ListAccountSettings = Action('ListAccountSettings')
ListAttributes = Action('ListAttributes')
ListClusters = Action('ListClusters')
ListContainerInstances = Action('ListContainerInstances')
ListServices = Action('ListServices')
ListTagsForResource = Action('ListTagsForResource')
ListTaskDefinitionFamilies = Action('ListTaskDefinitionFamilies')
ListTaskDefinitions = Action('ListTaskDefinitions')
ListTasks = Action('ListTasks')
Poll = Action('Poll')
PutAccountSetting = Action('PutAccountSetting')
PutAccountSettingDefault = Action('PutAccountSettingDefault')
PutAttributes = Action('PutAttributes')
RegisterContainerInstance = Action('RegisterContainerInstance')
RegisterTaskDefinition = Action('RegisterTaskDefinition')
RunTask = Action('RunTask')
StartTask = Action('StartTask')
StartTelemetrySession = Action('StartTelemetrySession')
StopTask = Action('StopTask')
SubmitContainerStateChange = Action('SubmitContainerStateChange')
SubmitTaskStateChange = Action('SubmitTaskStateChange')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateContainerAgent = Action('UpdateContainerAgent')
UpdateContainerInstancesState = Action('UpdateContainerInstancesState')
UpdateService = Action('UpdateService')
UpdateServicePrimaryTaskSet = Action('UpdateServicePrimaryTaskSet')
UpdateTaskSet = Action('UpdateTaskSet')



from awacs.aws import Allow, ArnEquals, AWSPrincipal, Condition
from awacs.aws import Policy, Statement
import awacs.sns as sns
import awacs.sqs as sqs


region = 'us-east-1'
account = '012345678891'

pd = Policy(
    Statement=[
        Statement(
            Effect=Allow,
            Principal=AWSPrincipal("210987654321"),
            Action=[sqs.SendMessage],
            Resource=[sqs.ARN(region, account, "your_queue_xyz"), ],
            Condition=Condition(
                ArnEquals(
                    "aws:SourceArn",
                    sns.ARN(region, '123456789012', 'your_special_topic_1')
                ),
            ),
        ),
    ],
)
print(pd.to_json())



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Elastic Transcoder'
prefix = 'elastictranscoder'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CancelJob = Action('CancelJob')
CreateJob = Action('CreateJob')
CreatePipeline = Action('CreatePipeline')
CreatePreset = Action('CreatePreset')
DeletePipeline = Action('DeletePipeline')
DeletePreset = Action('DeletePreset')
ListJobsByPipeline = Action('ListJobsByPipeline')
ListJobsByStatus = Action('ListJobsByStatus')
ListPipelines = Action('ListPipelines')
ListPresets = Action('ListPresets')
ReadJob = Action('ReadJob')
ReadPipeline = Action('ReadPipeline')
ReadPreset = Action('ReadPreset')
TestRole = Action('TestRole')
UpdatePipeline = Action('UpdatePipeline')
UpdatePipelineNotifications = Action('UpdatePipelineNotifications')
UpdatePipelineStatus = Action('UpdatePipelineStatus')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Elastic File System'
prefix = 'elasticfilesystem'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateFileSystem = Action('CreateFileSystem')
CreateMountTarget = Action('CreateMountTarget')
CreateTags = Action('CreateTags')
DeleteFileSystem = Action('DeleteFileSystem')
DeleteMountTarget = Action('DeleteMountTarget')
DeleteTags = Action('DeleteTags')
DescribeFileSystems = Action('DescribeFileSystems')
DescribeLifecycleConfiguration = Action('DescribeLifecycleConfiguration')
DescribeMountTargetSecurityGroups = \
    Action('DescribeMountTargetSecurityGroups')
DescribeMountTargets = Action('DescribeMountTargets')
DescribeTags = Action('DescribeTags')
ModifyMountTargetSecurityGroups = \
    Action('ModifyMountTargetSecurityGroups')
PutLifecycleConfiguration = Action('PutLifecycleConfiguration')
UpdateFileSystem = Action('UpdateFileSystem')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Mechanical Turk Crowd'
prefix = 'crowd'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


ApproveAssignment = Action('ApproveAssignment')
ApproveRejectedAssignment = Action('ApproveRejectedAssignment')
AssignQualification = Action('AssignQualification')
BlockWorker = Action('BlockWorker')
ChangeHITTypeOfHIT = Action('ChangeHITTypeOfHIT')
CreateHIT = Action('CreateHIT')
CreateQualificationType = Action('CreateQualificationType')
DisableHIT = Action('DisableHIT')
DisposeHIT = Action('DisposeHIT')
DisposeQualificationType = Action('DisposeQualificationType')
ExtendHIT = Action('ExtendHIT')
ForceExpireHIT = Action('ForceExpireHIT')
GetAccountBalance = Action('GetAccountBalance')
GetAssignment = Action('GetAssignment')
GetAssignmentsForHIT = Action('GetAssignmentsForHIT')
GetBlockedWorkers = Action('GetBlockedWorkers')
GetBonusPayments = Action('GetBonusPayments')
GetFileUploadURL = Action('GetFileUploadURL')
GetHIT = Action('GetHIT')
GetHITsForQualificationType = Action('GetHITsForQualificationType')
GetQualificationRequests = Action('GetQualificationRequests')
GetQualificationScore = Action('GetQualificationScore')
GetQualificationType = Action('GetQualificationType')
GetQualificationsForQualificationType = \
    Action('GetQualificationsForQualificationType')
GetRequesterStatistic = Action('GetRequesterStatistic')
GetRequesterWorkerStatistic = Action('GetRequesterWorkerStatistic')
GetReviewResultsForHIT = Action('GetReviewResultsForHIT')
GetReviewableHITs = Action('GetReviewableHITs')
GetTask = Action('GetTask')
GrantBonus = Action('GrantBonus')
GrantQualification = Action('GrantQualification')
NotifyWorkers = Action('NotifyWorkers')
PutTask = Action('PutTask')
RegisterHITType = Action('RegisterHITType')
RejectAssignment = Action('RejectAssignment')
RejectQualificationRequest = Action('RejectQualificationRequest')
RevokeQualification = Action('RevokeQualification')
SearchHITs = Action('SearchHITs')
SearchQualificationTypes = Action('SearchQualificationTypes')
SendTestEventNotification = Action('SendTestEventNotification')
SetHITAsReviewing = Action('SetHITAsReviewing')
SetHITTypeNotification = Action('SetHITTypeNotification')
UnblockWorker = Action('UnblockWorker')
UpdateQualificationScore = Action('UpdateQualificationScore')
UpdateQualificationType = Action('UpdateQualificationType')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Elasticsearch Service'
prefix = 'es'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AddTags = Action('AddTags')
CreateElasticsearchDomain = Action('CreateElasticsearchDomain')
DeleteElasticsearchDomain = Action('DeleteElasticsearchDomain')
DeleteElasticsearchServiceRole = Action('DeleteElasticsearchServiceRole')
DescribeElasticsearchDomain = Action('DescribeElasticsearchDomain')
DescribeElasticsearchDomainConfig = \
    Action('DescribeElasticsearchDomainConfig')
DescribeElasticsearchDomains = Action('DescribeElasticsearchDomains')
DescribeElasticsearchInstanceTypeLimits = \
    Action('DescribeElasticsearchInstanceTypeLimits')
DescribeReservedElasticsearchInstanceOfferings = \
    Action('DescribeReservedElasticsearchInstanceOfferings')
DescribeReservedElasticsearchInstances = \
    Action('DescribeReservedElasticsearchInstances')
ESHttpDelete = Action('ESHttpDelete')
ESHttpGet = Action('ESHttpGet')
ESHttpHead = Action('ESHttpHead')
ESHttpPost = Action('ESHttpPost')
ESHttpPut = Action('ESHttpPut')
GetCompatibleElasticsearchVersions = \
    Action('GetCompatibleElasticsearchVersions')
GetUpgradeHistory = Action('GetUpgradeHistory')
GetUpgradeStatus = Action('GetUpgradeStatus')
ListDomainNames = Action('ListDomainNames')
ListElasticsearchInstanceTypes = Action('ListElasticsearchInstanceTypes')
ListElasticsearchVersions = Action('ListElasticsearchVersions')
ListTags = Action('ListTags')
PurchaseReservedElasticsearchInstance = \
    Action('PurchaseReservedElasticsearchInstance')
RemoveTags = Action('RemoveTags')
UpdateElasticsearchDomainConfig = \
    Action('UpdateElasticsearchDomainConfig')
UpgradeElasticsearchDomain = Action('UpgradeElasticsearchDomain')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon DynamoDB'
prefix = 'dynamodb'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


BatchGetItem = Action('BatchGetItem')
BatchWriteItem = Action('BatchWriteItem')
ConditionCheckItem = Action('ConditionCheckItem')
CreateBackup = Action('CreateBackup')
CreateGlobalTable = Action('CreateGlobalTable')
CreateTable = Action('CreateTable')
DeleteBackup = Action('DeleteBackup')
DeleteItem = Action('DeleteItem')
DeleteTable = Action('DeleteTable')
DescribeBackup = Action('DescribeBackup')
DescribeContinuousBackups = Action('DescribeContinuousBackups')
DescribeGlobalTable = Action('DescribeGlobalTable')
DescribeGlobalTableSettings = Action('DescribeGlobalTableSettings')
DescribeLimits = Action('DescribeLimits')
DescribeReservedCapacity = Action('DescribeReservedCapacity')
DescribeReservedCapacityOfferings = \
    Action('DescribeReservedCapacityOfferings')
DescribeStream = Action('DescribeStream')
DescribeTable = Action('DescribeTable')
DescribeTimeToLive = Action('DescribeTimeToLive')
GetItem = Action('GetItem')
GetRecords = Action('GetRecords')
GetShardIterator = Action('GetShardIterator')
ListBackups = Action('ListBackups')
ListGlobalTables = Action('ListGlobalTables')
ListStreams = Action('ListStreams')
ListTables = Action('ListTables')
ListTagsOfResource = Action('ListTagsOfResource')
PurchaseReservedCapacityOfferings = \
    Action('PurchaseReservedCapacityOfferings')
PutItem = Action('PutItem')
Query = Action('Query')
RestoreTableFromBackup = Action('RestoreTableFromBackup')
RestoreTableToPointInTime = Action('RestoreTableToPointInTime')
Scan = Action('Scan')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateContinuousBackups = Action('UpdateContinuousBackups')
UpdateGlobalTable = Action('UpdateGlobalTable')
UpdateGlobalTableSettings = Action('UpdateGlobalTableSettings')
UpdateItem = Action('UpdateItem')
UpdateTable = Action('UpdateTable')
UpdateTimeToLive = Action('UpdateTimeToLive')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Storage Gateway'
prefix = 'storagegateway'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


ActivateGateway = Action('ActivateGateway')
AddCache = Action('AddCache')
AddTagsToResource = Action('AddTagsToResource')
AddUploadBuffer = Action('AddUploadBuffer')
AddWorkingStorage = Action('AddWorkingStorage')
AttachVolume = Action('AttachVolume')
CancelArchival = Action('CancelArchival')
CancelRetrieval = Action('CancelRetrieval')
CreateCachediSCSIVolume = Action('CreateCachediSCSIVolume')
CreateNFSFileShare = Action('CreateNFSFileShare')
CreateSMBFileShare = Action('CreateSMBFileShare')
CreateSnapshot = Action('CreateSnapshot')
CreateSnapshotFromVolumeRecoveryPoint = \
    Action('CreateSnapshotFromVolumeRecoveryPoint')
CreateStorediSCSIVolume = Action('CreateStorediSCSIVolume')
CreateTapeWithBarcode = Action('CreateTapeWithBarcode')
CreateTapes = Action('CreateTapes')
DeleteBandwidthRateLimit = Action('DeleteBandwidthRateLimit')
DeleteChapCredentials = Action('DeleteChapCredentials')
DeleteFileShare = Action('DeleteFileShare')
DeleteGateway = Action('DeleteGateway')
DeleteSnapshotSchedule = Action('DeleteSnapshotSchedule')
DeleteTape = Action('DeleteTape')
DeleteTapeArchive = Action('DeleteTapeArchive')
DeleteVolume = Action('DeleteVolume')
DescribeBandwidthRateLimit = Action('DescribeBandwidthRateLimit')
DescribeCache = Action('DescribeCache')
DescribeCachediSCSIVolumes = Action('DescribeCachediSCSIVolumes')
DescribeChapCredentials = Action('DescribeChapCredentials')
DescribeGatewayInformation = Action('DescribeGatewayInformation')
DescribeMaintenanceStartTime = Action('DescribeMaintenanceStartTime')
DescribeNFSFileShares = Action('DescribeNFSFileShares')
DescribeSMBFileShares = Action('DescribeSMBFileShares')
DescribeSMBSettings = Action('DescribeSMBSettings')
DescribeSnapshotSchedule = Action('DescribeSnapshotSchedule')
DescribeStorediSCSIVolumes = Action('DescribeStorediSCSIVolumes')
DescribeTapeArchives = Action('DescribeTapeArchives')
DescribeTapeRecoveryPoints = Action('DescribeTapeRecoveryPoints')
DescribeTapes = Action('DescribeTapes')
DescribeUploadBuffer = Action('DescribeUploadBuffer')
DescribeVTLDevices = Action('DescribeVTLDevices')
DescribeWorkingStorage = Action('DescribeWorkingStorage')
DetachVolume = Action('DetachVolume')
DisableGateway = Action('DisableGateway')
JoinDomain = Action('JoinDomain')
ListFileShares = Action('ListFileShares')
ListGateways = Action('ListGateways')
ListLocalDisks = Action('ListLocalDisks')
ListTagsForResource = Action('ListTagsForResource')
ListTapes = Action('ListTapes')
ListVolumeInitiators = Action('ListVolumeInitiators')
ListVolumeRecoveryPoints = Action('ListVolumeRecoveryPoints')
ListVolumes = Action('ListVolumes')
NotifyWhenUploaded = Action('NotifyWhenUploaded')
RefreshCache = Action('RefreshCache')
RemoveTagsFromResource = Action('RemoveTagsFromResource')
ResetCache = Action('ResetCache')
RetrieveTapeArchive = Action('RetrieveTapeArchive')
RetrieveTapeRecoveryPoint = Action('RetrieveTapeRecoveryPoint')
SetLocalConsolePassword = Action('SetLocalConsolePassword')
SetSMBGuestPassword = Action('SetSMBGuestPassword')
ShutdownGateway = Action('ShutdownGateway')
StartGateway = Action('StartGateway')
UpdateBandwidthRateLimit = Action('UpdateBandwidthRateLimit')
UpdateChapCredentials = Action('UpdateChapCredentials')
UpdateGatewayInformation = Action('UpdateGatewayInformation')
UpdateGatewaySoftwareNow = Action('UpdateGatewaySoftwareNow')
UpdateMaintenanceStartTime = Action('UpdateMaintenanceStartTime')
UpdateNFSFileShare = Action('UpdateNFSFileShare')
UpdateSMBFileShare = Action('UpdateSMBFileShare')
UpdateSnapshotSchedule = Action('UpdateSnapshotSchedule')
UpdateVTLDeviceType = Action('UpdateVTLDeviceType')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Elemental MediaPackage'
prefix = 'mediapackage'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateChannel = Action('CreateChannel')
CreateOriginEndpoint = Action('CreateOriginEndpoint')
DeleteChannel = Action('DeleteChannel')
DeleteOriginEndpoint = Action('DeleteOriginEndpoint')
DescribeChannel = Action('DescribeChannel')
DescribeOriginEndpoint = Action('DescribeOriginEndpoint')
ListChannels = Action('ListChannels')
ListOriginEndpoints = Action('ListOriginEndpoints')
ListTagsForResource = Action('ListTagsForResource')
RotateIngestEndpointCredentials = \
    Action('RotateIngestEndpointCredentials')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateChannel = Action('UpdateChannel')
UpdateOriginEndpoint = Action('UpdateOriginEndpoint')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Key Management Service'
prefix = 'kms'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CancelKeyDeletion = Action('CancelKeyDeletion')
ConnectCustomKeyStore = Action('ConnectCustomKeyStore')
CreateAlias = Action('CreateAlias')
CreateCustomKeyStore = Action('CreateCustomKeyStore')
CreateGrant = Action('CreateGrant')
CreateKey = Action('CreateKey')
Decrypt = Action('Decrypt')
DeleteAlias = Action('DeleteAlias')
DeleteCustomKeyStore = Action('DeleteCustomKeyStore')
DeleteImportedKeyMaterial = Action('DeleteImportedKeyMaterial')
DescribeCustomKeyStores = Action('DescribeCustomKeyStores')
DescribeKey = Action('DescribeKey')
DisableKey = Action('DisableKey')
DisableKeyRotation = Action('DisableKeyRotation')
DisconnectCustomKeyStore = Action('DisconnectCustomKeyStore')
EnableKey = Action('EnableKey')
EnableKeyRotation = Action('EnableKeyRotation')
Encrypt = Action('Encrypt')
GenerateDataKey = Action('GenerateDataKey')
GenerateDataKeyWithoutPlaintext = \
    Action('GenerateDataKeyWithoutPlaintext')
GenerateRandom = Action('GenerateRandom')
GetKeyPolicy = Action('GetKeyPolicy')
GetKeyRotationStatus = Action('GetKeyRotationStatus')
GetParametersForImport = Action('GetParametersForImport')
ImportKeyMaterial = Action('ImportKeyMaterial')
ListAliases = Action('ListAliases')
ListGrants = Action('ListGrants')
ListKeyPolicies = Action('ListKeyPolicies')
ListKeys = Action('ListKeys')
ListResourceTags = Action('ListResourceTags')
ListRetirableGrants = Action('ListRetirableGrants')
PutKeyPolicy = Action('PutKeyPolicy')
ReEncrypt = Action('ReEncrypt')
ReEncryptFrom = Action('ReEncryptFrom')
ReEncryptTo = Action('ReEncryptTo')
RetireGrant = Action('RetireGrant')
RevokeGrant = Action('RevokeGrant')
ScheduleKeyDeletion = Action('ScheduleKeyDeletion')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateAlias = Action('UpdateAlias')
UpdateCustomKeyStore = Action('UpdateCustomKeyStore')
UpdateKeyDescription = Action('UpdateKeyDescription')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Single Sign-On'
prefix = 'sso'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AddMemberToGroup = Action('AddMemberToGroup')
AssociateDirectory = Action('AssociateDirectory')
AssociateProfile = Action('AssociateProfile')
CreateAlias = Action('CreateAlias')
CreateApplicationInstance = Action('CreateApplicationInstance')
CreateApplicationInstanceCertificate = \
    Action('CreateApplicationInstanceCertificate')
CreateGroup = Action('CreateGroup')
CreatePermissionSet = Action('CreatePermissionSet')
CreateProfile = Action('CreateProfile')
CreateTrust = Action('CreateTrust')
CreateUser = Action('CreateUser')
DeleteApplicationInstance = Action('DeleteApplicationInstance')
DeleteApplicationInstanceCertificate = \
    Action('DeleteApplicationInstanceCertificate')
DeleteGroup = Action('DeleteGroup')
DeletePermissionSet = Action('DeletePermissionSet')
DeletePermissionsPolicy = Action('DeletePermissionsPolicy')
DeleteProfile = Action('DeleteProfile')
DeleteUser = Action('DeleteUser')
DescribeGroups = Action('DescribeGroups')
DescribePermissionsPolicies = Action('DescribePermissionsPolicies')
DescribeUsers = Action('DescribeUsers')
DisableUser = Action('DisableUser')
DisassociateDirectory = Action('DisassociateDirectory')
DisassociateProfile = Action('DisassociateProfile')
EnableUser = Action('EnableUser')
GetApplicationInstance = Action('GetApplicationInstance')
GetApplicationTemplate = Action('GetApplicationTemplate')
GetPermissionSet = Action('GetPermissionSet')
GetPermissionsPolicy = Action('GetPermissionsPolicy')
GetProfile = Action('GetProfile')
GetSSOConfiguration = Action('GetSSOConfiguration')
GetSSOStatus = Action('GetSSOStatus')
GetTrust = Action('GetTrust')
GetUserPoolInfo = Action('GetUserPoolInfo')
ImportApplicationInstanceServiceProviderMetadata = \
    Action('ImportApplicationInstanceServiceProviderMetadata')
ListApplicationInstanceCertificates = \
    Action('ListApplicationInstanceCertificates')
ListApplicationInstances = Action('ListApplicationInstances')
ListApplicationTemplates = Action('ListApplicationTemplates')
ListApplications = Action('ListApplications')
ListDirectoryAssociations = Action('ListDirectoryAssociations')
ListGroupsForUser = Action('ListGroupsForUser')
ListMembersInGroup = Action('ListMembersInGroup')
ListPermissionSets = Action('ListPermissionSets')
ListProfileAssociations = Action('ListProfileAssociations')
ListProfiles = Action('ListProfiles')
PutPermissionsPolicy = Action('PutPermissionsPolicy')
RemoveMemberFromGroup = Action('RemoveMemberFromGroup')
SearchGroups = Action('SearchGroups')
SearchUsers = Action('SearchUsers')
SetTemporaryPassword = Action('SetTemporaryPassword')
StartSSO = Action('StartSSO')
UpdateApplicationInstanceActiveCertificate = \
    Action('UpdateApplicationInstanceActiveCertificate')
UpdateApplicationInstanceDisplayData = \
    Action('UpdateApplicationInstanceDisplayData')
UpdateApplicationInstanceResponseConfiguration = \
    Action('UpdateApplicationInstanceResponseConfiguration')
UpdateApplicationInstanceResponseSchemaConfiguration = \
    Action('UpdateApplicationInstanceResponseSchemaConfiguration')
UpdateApplicationInstanceSecurityConfiguration = \
    Action('UpdateApplicationInstanceSecurityConfiguration')
UpdateApplicationInstanceServiceProviderConfiguration = \
    Action('UpdateApplicationInstanceServiceProviderConfiguration')
UpdateApplicationInstanceStatus = \
    Action('UpdateApplicationInstanceStatus')
UpdateDirectoryAssociation = Action('UpdateDirectoryAssociation')
UpdateGroup = Action('UpdateGroup')
UpdatePermissionSet = Action('UpdatePermissionSet')
UpdateProfile = Action('UpdateProfile')
UpdateSSOConfiguration = Action('UpdateSSOConfiguration')
UpdateTrust = Action('UpdateTrust')
UpdateUser = Action('UpdateUser')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Transcribe'
prefix = 'transcribe'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateVocabulary = Action('CreateVocabulary')
DeleteTranscriptionJob = Action('DeleteTranscriptionJob')
DeleteVocabulary = Action('DeleteVocabulary')
GetTranscriptionJob = Action('GetTranscriptionJob')
GetVocabulary = Action('GetVocabulary')
ListTranscriptionJobs = Action('ListTranscriptionJobs')
ListVocabularies = Action('ListVocabularies')
StartStreamTranscription = Action('StartStreamTranscription')
StartTranscriptionJob = Action('StartTranscriptionJob')
UpdateVocabulary = Action('UpdateVocabulary')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Elastic MapReduce'
prefix = 'elasticmapreduce'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AddInstanceFleet = Action('AddInstanceFleet')
AddInstanceGroups = Action('AddInstanceGroups')
AddJobFlowSteps = Action('AddJobFlowSteps')
AddTags = Action('AddTags')
CancelSteps = Action('CancelSteps')
CreateEditor = Action('CreateEditor')
CreateSecurityConfiguration = Action('CreateSecurityConfiguration')
DeleteEditor = Action('DeleteEditor')
DeleteSecurityConfiguration = Action('DeleteSecurityConfiguration')
DescribeCluster = Action('DescribeCluster')
DescribeEditor = Action('DescribeEditor')
DescribeJobFlows = Action('DescribeJobFlows')
DescribeSecurityConfiguration = Action('DescribeSecurityConfiguration')
DescribeStep = Action('DescribeStep')
ListBootstrapActions = Action('ListBootstrapActions')
ListClusters = Action('ListClusters')
ListEditors = Action('ListEditors')
ListInstanceFleets = Action('ListInstanceFleets')
ListInstanceGroups = Action('ListInstanceGroups')
ListInstances = Action('ListInstances')
ListSecurityConfigurations = Action('ListSecurityConfigurations')
ListSteps = Action('ListSteps')
ModifyInstanceFleet = Action('ModifyInstanceFleet')
ModifyInstanceGroups = Action('ModifyInstanceGroups')
OpenEditorInConsole = Action('OpenEditorInConsole')
PutAutoScalingPolicy = Action('PutAutoScalingPolicy')
RemoveAutoScalingPolicy = Action('RemoveAutoScalingPolicy')
RemoveTags = Action('RemoveTags')
RunJobFlow = Action('RunJobFlow')
SetTerminationProtection = Action('SetTerminationProtection')
SetVisibleToAllUsers = Action('SetVisibleToAllUsers')
StartEditor = Action('StartEditor')
StopEditor = Action('StopEditor')
TerminateJobFlows = Action('TerminateJobFlows')
ViewEventsFromAllClustersInConsole = \
    Action('ViewEventsFromAllClustersInConsole')



import unittest

from awacs.aws import PolicyDocument


class TestAWSObject(unittest.TestCase):
    def test_invalid_property(self):
        with self.assertRaises(AttributeError) as exc:
            # statement should be Statement
            PolicyDocument(Version='2012-10-17', statement=[])

        self.assertEqual(
            exc.exception.args[0],
            "'awacs.aws.PolicyDocument' object does not support attribute "
            "'statement'"
        )



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Amplify'
prefix = 'amplify'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateApp = Action('CreateApp')
CreateBranch = Action('CreateBranch')
CreateDomainAssociation = Action('CreateDomainAssociation')
DeleteApp = Action('DeleteApp')
DeleteBranch = Action('DeleteBranch')
DeleteDomainAssociation = Action('DeleteDomainAssociation')
DeleteJob = Action('DeleteJob')
GetApp = Action('GetApp')
GetBranch = Action('GetBranch')
GetDomainAssociation = Action('GetDomainAssociation')
GetJob = Action('GetJob')
ListApps = Action('ListApps')
ListBranches = Action('ListBranches')
ListDomainAssociations = Action('ListDomainAssociations')
ListJobs = Action('ListJobs')
StartJob = Action('StartJob')
StopJob = Action('StopJob')
UpdateApp = Action('UpdateApp')
UpdateBranch = Action('UpdateBranch')
UpdateDomainAssociation = Action('UpdateDomainAssociation')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS CloudHSM'
prefix = 'cloudhsm'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AddTagsToResource = Action('AddTagsToResource')
CreateCluster = Action('CreateCluster')
CreateHapg = Action('CreateHapg')
CreateHsm = Action('CreateHsm')
CreateLunaClient = Action('CreateLunaClient')
DeleteCluster = Action('DeleteCluster')
DeleteHapg = Action('DeleteHapg')
DeleteHsm = Action('DeleteHsm')
DeleteLunaClient = Action('DeleteLunaClient')
DescribeBackups = Action('DescribeBackups')
DescribeClusters = Action('DescribeClusters')
DescribeHapg = Action('DescribeHapg')
DescribeHsm = Action('DescribeHsm')
DescribeLunaClient = Action('DescribeLunaClient')
GetConfig = Action('GetConfig')
InitializeCluster = Action('InitializeCluster')
ListAvailableZones = Action('ListAvailableZones')
ListHapgs = Action('ListHapgs')
ListHsms = Action('ListHsms')
ListLunaClients = Action('ListLunaClients')
ListTags = Action('ListTags')
ListTagsForResource = Action('ListTagsForResource')
ModifyHapg = Action('ModifyHapg')
ModifyHsm = Action('ModifyHsm')
ModifyLunaClient = Action('ModifyLunaClient')
RemoveTagsFromResource = Action('RemoveTagsFromResource')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Migration Hub'
prefix = 'mgh'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AssociateCreatedArtifact = Action('AssociateCreatedArtifact')
AssociateDiscoveredResource = Action('AssociateDiscoveredResource')
CreateProgressUpdateStream = Action('CreateProgressUpdateStream')
DeleteProgressUpdateStream = Action('DeleteProgressUpdateStream')
DescribeApplicationState = Action('DescribeApplicationState')
DescribeMigrationTask = Action('DescribeMigrationTask')
DisassociateCreatedArtifact = Action('DisassociateCreatedArtifact')
DisassociateDiscoveredResource = Action('DisassociateDiscoveredResource')
ImportMigrationTask = Action('ImportMigrationTask')
ListCreatedArtifacts = Action('ListCreatedArtifacts')
ListDiscoveredResources = Action('ListDiscoveredResources')
ListMigrationTasks = Action('ListMigrationTasks')
ListProgressUpdateStreams = Action('ListProgressUpdateStreams')
NotifyApplicationState = Action('NotifyApplicationState')
NotifyMigrationTaskState = Action('NotifyMigrationTaskState')
PutResourceAttributes = Action('PutResourceAttributes')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Snowball'
prefix = 'snowball'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CancelCluster = Action('CancelCluster')
CancelJob = Action('CancelJob')
CreateAddress = Action('CreateAddress')
CreateCluster = Action('CreateCluster')
CreateJob = Action('CreateJob')
DescribeAddress = Action('DescribeAddress')
DescribeAddresses = Action('DescribeAddresses')
DescribeCluster = Action('DescribeCluster')
DescribeJob = Action('DescribeJob')
GetJobManifest = Action('GetJobManifest')
GetJobUnlockCode = Action('GetJobUnlockCode')
GetSnowballUsage = Action('GetSnowballUsage')
ListClusterJobs = Action('ListClusterJobs')
ListClusters = Action('ListClusters')
ListJobs = Action('ListJobs')
UpdateCluster = Action('UpdateCluster')
UpdateJob = Action('UpdateJob')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Athena'
prefix = 'athena'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


BatchGetNamedQuery = Action('BatchGetNamedQuery')
BatchGetQueryExecution = Action('BatchGetQueryExecution')
CancelQueryExecution = Action('CancelQueryExecution')
CreateNamedQuery = Action('CreateNamedQuery')
CreateWorkGroup = Action('CreateWorkGroup')
DeleteNamedQuery = Action('DeleteNamedQuery')
DeleteWorkGroup = Action('DeleteWorkGroup')
GetCatalogs = Action('GetCatalogs')
GetExecutionEngine = Action('GetExecutionEngine')
GetExecutionEngines = Action('GetExecutionEngines')
GetNamedQuery = Action('GetNamedQuery')
GetNamespace = Action('GetNamespace')
GetNamespaces = Action('GetNamespaces')
GetQueryExecution = Action('GetQueryExecution')
GetQueryExecutions = Action('GetQueryExecutions')
GetQueryResults = Action('GetQueryResults')
GetQueryResultsStream = Action('GetQueryResultsStream')
GetTable = Action('GetTable')
GetTables = Action('GetTables')
GetWorkGroup = Action('GetWorkGroup')
ListNamedQueries = Action('ListNamedQueries')
ListQueryExecutions = Action('ListQueryExecutions')
ListTagsForResource = Action('ListTagsForResource')
ListWorkGroups = Action('ListWorkGroups')
RunQuery = Action('RunQuery')
StartQueryExecution = Action('StartQueryExecution')
StopQueryExecution = Action('StopQueryExecution')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateWorkGroup = Action('UpdateWorkGroup')



import unittest

from awacs.ec2 import ARN


class TestARN(unittest.TestCase):
    def test_aws(self):
        arn = ARN("image/ami", "us-east-1", "account")
        self.assertEqual(
            arn.JSONrepr(), "arn:aws:ec2:us-east-1:account:image/ami")

    def test_cn(self):
        arn = ARN("image/ami", "cn-north-1", "account")
        self.assertEqual(
            arn.JSONrepr(), "arn:aws-cn:ec2:cn-north-1:account:image/ami")

    def test_gov(self):
        arn = ARN("image/ami", "us-gov-west-1", "account")
        self.assertEqual(
            arn.JSONrepr(),
            "arn:aws-us-gov:ec2:us-gov-west-1:account:image/ami")



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Direct Connect'
prefix = 'directconnect'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AcceptDirectConnectGatewayAssociationProposal = \
    Action('AcceptDirectConnectGatewayAssociationProposal')
AllocateConnectionOnInterconnect = \
    Action('AllocateConnectionOnInterconnect')
AllocateHostedConnection = Action('AllocateHostedConnection')
AllocatePrivateVirtualInterface = \
    Action('AllocatePrivateVirtualInterface')
AllocatePublicVirtualInterface = Action('AllocatePublicVirtualInterface')
AllocateTransitVirtualInterface = \
    Action('AllocateTransitVirtualInterface')
AssociateConnectionWithLag = Action('AssociateConnectionWithLag')
AssociateHostedConnection = Action('AssociateHostedConnection')
AssociateVirtualInterface = Action('AssociateVirtualInterface')
ConfirmConnection = Action('ConfirmConnection')
ConfirmPrivateVirtualInterface = Action('ConfirmPrivateVirtualInterface')
ConfirmPublicVirtualInterface = Action('ConfirmPublicVirtualInterface')
ConfirmTransitVirtualInterface = Action('ConfirmTransitVirtualInterface')
CreateBGPPeer = Action('CreateBGPPeer')
CreateConnection = Action('CreateConnection')
CreateDirectConnectGateway = Action('CreateDirectConnectGateway')
CreateDirectConnectGatewayAssociation = \
    Action('CreateDirectConnectGatewayAssociation')
CreateDirectConnectGatewayAssociationProposal = \
    Action('CreateDirectConnectGatewayAssociationProposal')
CreateInterconnect = Action('CreateInterconnect')
CreateLag = Action('CreateLag')
CreatePrivateVirtualInterface = Action('CreatePrivateVirtualInterface')
CreatePublicVirtualInterface = Action('CreatePublicVirtualInterface')
CreateTransitVirtualInterface = Action('CreateTransitVirtualInterface')
DeleteBGPPeer = Action('DeleteBGPPeer')
DeleteConnection = Action('DeleteConnection')
DeleteDirectConnectGateway = Action('DeleteDirectConnectGateway')
DeleteDirectConnectGatewayAssociation = \
    Action('DeleteDirectConnectGatewayAssociation')
DeleteDirectConnectGatewayAssociationProposal = \
    Action('DeleteDirectConnectGatewayAssociationProposal')
DeleteInterconnect = Action('DeleteInterconnect')
DeleteLag = Action('DeleteLag')
DeleteVirtualInterface = Action('DeleteVirtualInterface')
DescribeConnectionLoa = Action('DescribeConnectionLoa')
DescribeConnections = Action('DescribeConnections')
DescribeConnectionsOnInterconnect = \
    Action('DescribeConnectionsOnInterconnect')
DescribeDirectConnectGatewayAssociationProposals = \
    Action('DescribeDirectConnectGatewayAssociationProposals')
DescribeDirectConnectGatewayAssociations = \
    Action('DescribeDirectConnectGatewayAssociations')
DescribeDirectConnectGatewayAttachments = \
    Action('DescribeDirectConnectGatewayAttachments')
DescribeDirectConnectGateways = Action('DescribeDirectConnectGateways')
DescribeHostedConnections = Action('DescribeHostedConnections')
DescribeInterconnectLoa = Action('DescribeInterconnectLoa')
DescribeInterconnects = Action('DescribeInterconnects')
DescribeLags = Action('DescribeLags')
DescribeLoa = Action('DescribeLoa')
DescribeLocations = Action('DescribeLocations')
DescribeTags = Action('DescribeTags')
DescribeVirtualGateways = Action('DescribeVirtualGateways')
DescribeVirtualInterfaces = Action('DescribeVirtualInterfaces')
DisassociateConnectionFromLag = Action('DisassociateConnectionFromLag')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateDirectConnectGatewayAssociation = \
    Action('UpdateDirectConnectGatewayAssociation')
UpdateLag = Action('UpdateLag')
UpdateVirtualInterfaceAttributes = \
    Action('UpdateVirtualInterfaceAttributes')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Elemental MediaConnect'
prefix = 'mediaconnect'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AddFlowOutputs = Action('AddFlowOutputs')
CreateFlow = Action('CreateFlow')
DeleteFlow = Action('DeleteFlow')
DescribeFlow = Action('DescribeFlow')
GrantFlowEntitlements = Action('GrantFlowEntitlements')
ListEntitlements = Action('ListEntitlements')
ListFlows = Action('ListFlows')
RemoveFlowOutput = Action('RemoveFlowOutput')
RevokeFlowEntitlement = Action('RevokeFlowEntitlement')
StartFlow = Action('StartFlow')
StopFlow = Action('StopFlow')
UpdateFlowEntitlement = Action('UpdateFlowEntitlement')
UpdateFlowOutput = Action('UpdateFlowOutput')
UpdateFlowSource = Action('UpdateFlowSource')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon EC2 Container Registry'
prefix = 'ecr'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


BatchCheckLayerAvailability = Action('BatchCheckLayerAvailability')
BatchDeleteImage = Action('BatchDeleteImage')
BatchGetImage = Action('BatchGetImage')
CompleteLayerUpload = Action('CompleteLayerUpload')
CreateRepository = Action('CreateRepository')
DeleteLifecyclePolicy = Action('DeleteLifecyclePolicy')
DeleteRepository = Action('DeleteRepository')
DeleteRepositoryPolicy = Action('DeleteRepositoryPolicy')
DescribeImages = Action('DescribeImages')
DescribeRepositories = Action('DescribeRepositories')
GetAuthorizationToken = Action('GetAuthorizationToken')
GetDownloadUrlForLayer = Action('GetDownloadUrlForLayer')
GetLifecyclePolicy = Action('GetLifecyclePolicy')
GetLifecyclePolicyPreview = Action('GetLifecyclePolicyPreview')
GetRepositoryPolicy = Action('GetRepositoryPolicy')
InitiateLayerUpload = Action('InitiateLayerUpload')
ListImages = Action('ListImages')
ListTagsForResource = Action('ListTagsForResource')
PutImage = Action('PutImage')
PutLifecyclePolicy = Action('PutLifecyclePolicy')
SetRepositoryPolicy = Action('SetRepositoryPolicy')
StartLifecyclePolicyPreview = Action('StartLifecyclePolicyPreview')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UploadLayerPart = Action('UploadLayerPart')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'DataSync'
prefix = 'datasync'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CancelTaskExecution = Action('CancelTaskExecution')
CreateAgent = Action('CreateAgent')
CreateLocationEfs = Action('CreateLocationEfs')
CreateLocationNfs = Action('CreateLocationNfs')
CreateLocationS3 = Action('CreateLocationS3')
CreateTask = Action('CreateTask')
DeleteAgent = Action('DeleteAgent')
DeleteLocation = Action('DeleteLocation')
DeleteTask = Action('DeleteTask')
DescribeAgent = Action('DescribeAgent')
DescribeLocationEfs = Action('DescribeLocationEfs')
DescribeLocationNfs = Action('DescribeLocationNfs')
DescribeLocationS3 = Action('DescribeLocationS3')
DescribeTask = Action('DescribeTask')
DescribeTaskExecution = Action('DescribeTaskExecution')
ListAgents = Action('ListAgents')
ListLocations = Action('ListLocations')
ListTagsForResource = Action('ListTagsForResource')
ListTaskExecutions = Action('ListTaskExecutions')
ListTasks = Action('ListTasks')
StartTaskExecution = Action('StartTaskExecution')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateAgent = Action('UpdateAgent')
UpdateTask = Action('UpdateTask')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS WAF Regional'
prefix = 'waf-regional'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AssociateWebACL = Action('AssociateWebACL')
CreateByteMatchSet = Action('CreateByteMatchSet')
CreateGeoMatchSet = Action('CreateGeoMatchSet')
CreateIPSet = Action('CreateIPSet')
CreateRateBasedRule = Action('CreateRateBasedRule')
CreateRegexMatchSet = Action('CreateRegexMatchSet')
CreateRegexPatternSet = Action('CreateRegexPatternSet')
CreateRule = Action('CreateRule')
CreateRuleGroup = Action('CreateRuleGroup')
CreateSizeConstraintSet = Action('CreateSizeConstraintSet')
CreateSqlInjectionMatchSet = Action('CreateSqlInjectionMatchSet')
CreateWebACL = Action('CreateWebACL')
CreateXssMatchSet = Action('CreateXssMatchSet')
DeleteByteMatchSet = Action('DeleteByteMatchSet')
DeleteGeoMatchSet = Action('DeleteGeoMatchSet')
DeleteIPSet = Action('DeleteIPSet')
DeleteLoggingConfiguration = Action('DeleteLoggingConfiguration')
DeletePermissionPolicy = Action('DeletePermissionPolicy')
DeleteRateBasedRule = Action('DeleteRateBasedRule')
DeleteRegexMatchSet = Action('DeleteRegexMatchSet')
DeleteRegexPatternSet = Action('DeleteRegexPatternSet')
DeleteRule = Action('DeleteRule')
DeleteRuleGroup = Action('DeleteRuleGroup')
DeleteSizeConstraintSet = Action('DeleteSizeConstraintSet')
DeleteSqlInjectionMatchSet = Action('DeleteSqlInjectionMatchSet')
DeleteWebACL = Action('DeleteWebACL')
DeleteXssMatchSet = Action('DeleteXssMatchSet')
DisassociateWebACL = Action('DisassociateWebACL')
GetByteMatchSet = Action('GetByteMatchSet')
GetChangeToken = Action('GetChangeToken')
GetChangeTokenStatus = Action('GetChangeTokenStatus')
GetGeoMatchSet = Action('GetGeoMatchSet')
GetIPSet = Action('GetIPSet')
GetLoggingConfiguration = Action('GetLoggingConfiguration')
GetPermissionPolicy = Action('GetPermissionPolicy')
GetRateBasedRule = Action('GetRateBasedRule')
GetRateBasedRuleManagedKeys = Action('GetRateBasedRuleManagedKeys')
GetRegexMatchSet = Action('GetRegexMatchSet')
GetRegexPatternSet = Action('GetRegexPatternSet')
GetRule = Action('GetRule')
GetRuleGroup = Action('GetRuleGroup')
GetSampledRequests = Action('GetSampledRequests')
GetSizeConstraintSet = Action('GetSizeConstraintSet')
GetSqlInjectionMatchSet = Action('GetSqlInjectionMatchSet')
GetWebACL = Action('GetWebACL')
GetWebACLForResource = Action('GetWebACLForResource')
GetXssMatchSet = Action('GetXssMatchSet')
ListActivatedRulesInRuleGroup = Action('ListActivatedRulesInRuleGroup')
ListByteMatchSets = Action('ListByteMatchSets')
ListGeoMatchSets = Action('ListGeoMatchSets')
ListIPSets = Action('ListIPSets')
ListLoggingConfigurations = Action('ListLoggingConfigurations')
ListRateBasedRules = Action('ListRateBasedRules')
ListRegexMatchSets = Action('ListRegexMatchSets')
ListRegexPatternSets = Action('ListRegexPatternSets')
ListResourcesForWebACL = Action('ListResourcesForWebACL')
ListRuleGroups = Action('ListRuleGroups')
ListRules = Action('ListRules')
ListSizeConstraintSets = Action('ListSizeConstraintSets')
ListSqlInjectionMatchSets = Action('ListSqlInjectionMatchSets')
ListSubscribedRuleGroups = Action('ListSubscribedRuleGroups')
ListTagsForResource = Action('ListTagsForResource')
ListWebACLs = Action('ListWebACLs')
ListXssMatchSets = Action('ListXssMatchSets')
PutLoggingConfiguration = Action('PutLoggingConfiguration')
PutPermissionPolicy = Action('PutPermissionPolicy')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateByteMatchSet = Action('UpdateByteMatchSet')
UpdateGeoMatchSet = Action('UpdateGeoMatchSet')
UpdateIPSet = Action('UpdateIPSet')
UpdateRateBasedRule = Action('UpdateRateBasedRule')
UpdateRegexMatchSet = Action('UpdateRegexMatchSet')
UpdateRegexPatternSet = Action('UpdateRegexPatternSet')
UpdateRule = Action('UpdateRule')
UpdateRuleGroup = Action('UpdateRuleGroup')
UpdateSizeConstraintSet = Action('UpdateSizeConstraintSet')
UpdateSqlInjectionMatchSet = Action('UpdateSqlInjectionMatchSet')
UpdateWebACL = Action('UpdateWebACL')
UpdateXssMatchSet = Action('UpdateXssMatchSet')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon WorkSpaces'
prefix = 'workspaces'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AssociateIpGroups = Action('AssociateIpGroups')
AuthorizeIpRules = Action('AuthorizeIpRules')
CreateIpGroup = Action('CreateIpGroup')
CreateTags = Action('CreateTags')
CreateWorkspaces = Action('CreateWorkspaces')
DeleteIpGroup = Action('DeleteIpGroup')
DeleteTags = Action('DeleteTags')
DeleteWorkspaceImage = Action('DeleteWorkspaceImage')
DescribeAccount = Action('DescribeAccount')
DescribeAccountModifications = Action('DescribeAccountModifications')
DescribeClientProperties = Action('DescribeClientProperties')
DescribeIpGroups = Action('DescribeIpGroups')
DescribeTags = Action('DescribeTags')
DescribeWorkspaceBundles = Action('DescribeWorkspaceBundles')
DescribeWorkspaceDirectories = Action('DescribeWorkspaceDirectories')
DescribeWorkspaceImages = Action('DescribeWorkspaceImages')
DescribeWorkspaces = Action('DescribeWorkspaces')
DescribeWorkspacesConnectionStatus = \
    Action('DescribeWorkspacesConnectionStatus')
DisassociateIpGroups = Action('DisassociateIpGroups')
ImportWorkspaceImage = Action('ImportWorkspaceImage')
ListAvailableManagementCidrRanges = \
    Action('ListAvailableManagementCidrRanges')
ModifyAccount = Action('ModifyAccount')
ModifyClientProperties = Action('ModifyClientProperties')
ModifyWorkspaceProperties = Action('ModifyWorkspaceProperties')
ModifyWorkspaceState = Action('ModifyWorkspaceState')
RebootWorkspaces = Action('RebootWorkspaces')
RebuildWorkspaces = Action('RebuildWorkspaces')
RevokeIpRules = Action('RevokeIpRules')
StartWorkspaces = Action('StartWorkspaces')
StopWorkspaces = Action('StopWorkspaces')
TerminateWorkspaces = Action('TerminateWorkspaces')
UpdateRulesOfIpGroup = Action('UpdateRulesOfIpGroup')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon CloudWatch Events'
prefix = 'events'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


ActivateEventSource = Action('ActivateEventSource')
CreateEventBus = Action('CreateEventBus')
CreatePartnerEventSource = Action('CreatePartnerEventSource')
DeactivateEventSource = Action('DeactivateEventSource')
DeleteEventBus = Action('DeleteEventBus')
DeletePartnerEventSource = Action('DeletePartnerEventSource')
DeleteRule = Action('DeleteRule')
DescribeEventBus = Action('DescribeEventBus')
DescribeEventSource = Action('DescribeEventSource')
DescribePartnerEventSource = Action('DescribePartnerEventSource')
DescribeRule = Action('DescribeRule')
DisableRule = Action('DisableRule')
EnableRule = Action('EnableRule')
ListEventBuses = Action('ListEventBuses')
ListEventSources = Action('ListEventSources')
ListPartnerEventSourceAccounts = Action('ListPartnerEventSourceAccounts')
ListPartnerEventSources = Action('ListPartnerEventSources')
ListRuleNamesByTarget = Action('ListRuleNamesByTarget')
ListRules = Action('ListRules')
ListTagsForResource = Action('ListTagsForResource')
ListTargetsByRule = Action('ListTargetsByRule')
PutEvents = Action('PutEvents')
PutPartnerEvents = Action('PutPartnerEvents')
PutPermission = Action('PutPermission')
PutRule = Action('PutRule')
PutTargets = Action('PutTargets')
RemovePermission = Action('RemovePermission')
RemoveTargets = Action('RemoveTargets')
TagResource = Action('TagResource')
TestEventPattern = Action('TestEventPattern')
UntagResource = Action('UntagResource')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon ElastiCache'
prefix = 'elasticache'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AddTagsToResource = Action('AddTagsToResource')
AuthorizeCacheSecurityGroupIngress = \
    Action('AuthorizeCacheSecurityGroupIngress')
CopySnapshot = Action('CopySnapshot')
CreateCacheCluster = Action('CreateCacheCluster')
CreateCacheParameterGroup = Action('CreateCacheParameterGroup')
CreateCacheSecurityGroup = Action('CreateCacheSecurityGroup')
CreateCacheSubnetGroup = Action('CreateCacheSubnetGroup')
CreateReplicationGroup = Action('CreateReplicationGroup')
CreateSnapshot = Action('CreateSnapshot')
DecreaseReplicaCount = Action('DecreaseReplicaCount')
DeleteCacheCluster = Action('DeleteCacheCluster')
DeleteCacheParameterGroup = Action('DeleteCacheParameterGroup')
DeleteCacheSecurityGroup = Action('DeleteCacheSecurityGroup')
DeleteCacheSubnetGroup = Action('DeleteCacheSubnetGroup')
DeleteReplicationGroup = Action('DeleteReplicationGroup')
DeleteSnapshot = Action('DeleteSnapshot')
DescribeCacheClusters = Action('DescribeCacheClusters')
DescribeCacheEngineVersions = Action('DescribeCacheEngineVersions')
DescribeCacheParameterGroups = Action('DescribeCacheParameterGroups')
DescribeCacheParameters = Action('DescribeCacheParameters')
DescribeCacheSecurityGroups = Action('DescribeCacheSecurityGroups')
DescribeCacheSubnetGroups = Action('DescribeCacheSubnetGroups')
DescribeEngineDefaultParameters = \
    Action('DescribeEngineDefaultParameters')
DescribeEvents = Action('DescribeEvents')
DescribeReplicationGroups = Action('DescribeReplicationGroups')
DescribeReservedCacheNodes = Action('DescribeReservedCacheNodes')
DescribeReservedCacheNodesOfferings = \
    Action('DescribeReservedCacheNodesOfferings')
DescribeSnapshots = Action('DescribeSnapshots')
IncreaseReplicaCount = Action('IncreaseReplicaCount')
ListAllowedNodeTypeModifications = \
    Action('ListAllowedNodeTypeModifications')
ListTagsForResource = Action('ListTagsForResource')
ModifyCacheCluster = Action('ModifyCacheCluster')
ModifyCacheParameterGroup = Action('ModifyCacheParameterGroup')
ModifyCacheSubnetGroup = Action('ModifyCacheSubnetGroup')
ModifyReplicationGroup = Action('ModifyReplicationGroup')
ModifyReplicationGroupShardConfiguration = \
    Action('ModifyReplicationGroupShardConfiguration')
PurchaseReservedCacheNodesOffering = \
    Action('PurchaseReservedCacheNodesOffering')
RebootCacheCluster = Action('RebootCacheCluster')
RemoveTagsFromResource = Action('RemoveTagsFromResource')
ResetCacheParameterGroup = Action('ResetCacheParameterGroup')
RevokeCacheSecurityGroupIngress = \
    Action('RevokeCacheSecurityGroupIngress')
TestFailover = Action('TestFailover')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Glacier'
prefix = 'glacier'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AbortMultipartUpload = Action('AbortMultipartUpload')
AbortVaultLock = Action('AbortVaultLock')
AddTagsToVault = Action('AddTagsToVault')
CompleteMultipartUpload = Action('CompleteMultipartUpload')
CompleteVaultLock = Action('CompleteVaultLock')
CreateVault = Action('CreateVault')
DeleteArchive = Action('DeleteArchive')
DeleteVault = Action('DeleteVault')
DeleteVaultAccessPolicy = Action('DeleteVaultAccessPolicy')
DeleteVaultNotifications = Action('DeleteVaultNotifications')
DescribeJob = Action('DescribeJob')
DescribeVault = Action('DescribeVault')
GetDataRetrievalPolicy = Action('GetDataRetrievalPolicy')
GetJobOutput = Action('GetJobOutput')
GetVaultAccessPolicy = Action('GetVaultAccessPolicy')
GetVaultLock = Action('GetVaultLock')
GetVaultNotifications = Action('GetVaultNotifications')
InitiateJob = Action('InitiateJob')
InitiateMultipartUpload = Action('InitiateMultipartUpload')
InitiateVaultLock = Action('InitiateVaultLock')
ListJobs = Action('ListJobs')
ListMultipartUploads = Action('ListMultipartUploads')
ListParts = Action('ListParts')
ListProvisionedCapacity = Action('ListProvisionedCapacity')
ListTagsForVault = Action('ListTagsForVault')
ListVaults = Action('ListVaults')
PurchaseProvisionedCapacity = Action('PurchaseProvisionedCapacity')
RemoveTagsFromVault = Action('RemoveTagsFromVault')
SetDataRetrievalPolicy = Action('SetDataRetrievalPolicy')
SetVaultAccessPolicy = Action('SetVaultAccessPolicy')
SetVaultNotifications = Action('SetVaultNotifications')
UploadArchive = Action('UploadArchive')
UploadMultipartPart = Action('UploadMultipartPart')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Comprehend'
prefix = 'comprehend'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


BatchDetectDominantLanguage = Action('BatchDetectDominantLanguage')
BatchDetectEntities = Action('BatchDetectEntities')
BatchDetectKeyPhrases = Action('BatchDetectKeyPhrases')
BatchDetectSentiment = Action('BatchDetectSentiment')
BatchDetectSyntax = Action('BatchDetectSyntax')
CreateDocumentClassifier = Action('CreateDocumentClassifier')
CreateEntityRecognizer = Action('CreateEntityRecognizer')
DeleteDocumentClassifier = Action('DeleteDocumentClassifier')
DeleteEntityRecognizer = Action('DeleteEntityRecognizer')
DescribeDocumentClassificationJob = \
    Action('DescribeDocumentClassificationJob')
DescribeDocumentClassifier = Action('DescribeDocumentClassifier')
DescribeDominantLanguageDetectionJob = \
    Action('DescribeDominantLanguageDetectionJob')
DescribeEntitiesDetectionJob = Action('DescribeEntitiesDetectionJob')
DescribeEntityRecognizer = Action('DescribeEntityRecognizer')
DescribeKeyPhrasesDetectionJob = Action('DescribeKeyPhrasesDetectionJob')
DescribeSentimentDetectionJob = Action('DescribeSentimentDetectionJob')
DescribeTopicsDetectionJob = Action('DescribeTopicsDetectionJob')
DetectDominantLanguage = Action('DetectDominantLanguage')
DetectEntities = Action('DetectEntities')
DetectKeyPhrases = Action('DetectKeyPhrases')
DetectSentiment = Action('DetectSentiment')
DetectSyntax = Action('DetectSyntax')
ListDocumentClassificationJobs = Action('ListDocumentClassificationJobs')
ListDocumentClassifiers = Action('ListDocumentClassifiers')
ListDominantLanguageDetectionJobs = \
    Action('ListDominantLanguageDetectionJobs')
ListEntitiesDetectionJobs = Action('ListEntitiesDetectionJobs')
ListEntityRecognizers = Action('ListEntityRecognizers')
ListKeyPhrasesDetectionJobs = Action('ListKeyPhrasesDetectionJobs')
ListSentimentDetectionJobs = Action('ListSentimentDetectionJobs')
ListTagsForResource = Action('ListTagsForResource')
ListTopicsDetectionJobs = Action('ListTopicsDetectionJobs')
StartDocumentClassificationJob = Action('StartDocumentClassificationJob')
StartDominantLanguageDetectionJob = \
    Action('StartDominantLanguageDetectionJob')
StartEntitiesDetectionJob = Action('StartEntitiesDetectionJob')
StartKeyPhrasesDetectionJob = Action('StartKeyPhrasesDetectionJob')
StartSentimentDetectionJob = Action('StartSentimentDetectionJob')
StartTopicsDetectionJob = Action('StartTopicsDetectionJob')
StopDominantLanguageDetectionJob = \
    Action('StopDominantLanguageDetectionJob')
StopEntitiesDetectionJob = Action('StopEntitiesDetectionJob')
StopKeyPhrasesDetectionJob = Action('StopKeyPhrasesDetectionJob')
StopSentimentDetectionJob = Action('StopSentimentDetectionJob')
StopTrainingDocumentClassifier = Action('StopTrainingDocumentClassifier')
StopTrainingEntityRecognizer = Action('StopTrainingEntityRecognizer')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Certificate Manager Private Certificate Authority'
prefix = 'acm-pca'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateCertificateAuthority = Action('CreateCertificateAuthority')
CreateCertificateAuthorityAuditReport = \
    Action('CreateCertificateAuthorityAuditReport')
CreatePermission = Action('CreatePermission')
DeleteCertificateAuthority = Action('DeleteCertificateAuthority')
DeletePermission = Action('DeletePermission')
DescribeCertificateAuthority = Action('DescribeCertificateAuthority')
DescribeCertificateAuthorityAuditReport = \
    Action('DescribeCertificateAuthorityAuditReport')
GetCertificate = Action('GetCertificate')
GetCertificateAuthorityCertificate = \
    Action('GetCertificateAuthorityCertificate')
GetCertificateAuthorityCsr = Action('GetCertificateAuthorityCsr')
ImportCertificateAuthorityCertificate = \
    Action('ImportCertificateAuthorityCertificate')
IssueCertificate = Action('IssueCertificate')
ListCertificateAuthorities = Action('ListCertificateAuthorities')
ListPermissions = Action('ListPermissions')
ListTags = Action('ListTags')
RestoreCertificateAuthority = Action('RestoreCertificateAuthority')
RevokeCertificate = Action('RevokeCertificate')
TagCertificateAuthority = Action('TagCertificateAuthority')
UntagCertificateAuthority = Action('UntagCertificateAuthority')
UpdateCertificateAuthority = Action('UpdateCertificateAuthority')
